#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/10 14:00
Desc: 中国外汇交易中心暨全国银行间同业拆借中心
https://www.chinamoney.com.cn/chinese/scsjzqxx/
"""

import functools

import pandas as pd
import requests
from akshare.utils.tqdm import get_tqdm
from akshare.bond.bond_china import bond_china_close_return_map


@functools.lru_cache()
def bond_info_cm_query(symbol: str = "评级等级") -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-查询相关指标的参数
    https://www.chinamoney.com.cn/chinese/scsjzqxx/
    :param symbol: choice of {"主承销商", "债券类型", "息票类型", "发行年份", "评级等级"}
    :type symbol: str
    :return: 查询相关指标的参数
    :rtype: pandas.DataFrame
    """
    bond_china_close_return_map()
    if symbol == "主承销商":
        url = "https://www.chinamoney.com.cn/ags/ms/cm-u-bond-md/EntyFullNameSearchCondition"
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/109.0.0.0 Safari/537.36"
        }
        r = requests.post(url, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["enty"])
        temp_df.columns = ["code", "name"]
        temp_df = temp_df[["name", "code"]]
        return temp_df
    else:
        symbol_map = {
            "债券类型": "bondType",
            "息票类型": "couponType",
            "发行年份": "issueYear",
            "评级等级": "bondRtngShrt",
        }
        url = "https://www.chinamoney.com.cn/ags/ms/cm-u-bond-md/BondBaseInfoSearchCondition"
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/109.0.0.0 Safari/537.36"
        }
        r = requests.post(url, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"][f"{symbol_map[symbol]}"])
        if temp_df.shape[1] == 1:
            temp_df.columns = ["name"]
            temp_df["code"] = temp_df["name"]
        temp_df.columns = ["code", "name"]
        temp_df = temp_df[["name", "code"]]
        return temp_df


@functools.lru_cache()
def bond_info_cm(
    bond_name: str = "",
    bond_code: str = "",
    bond_issue: str = "",
    bond_type: str = "",
    coupon_type: str = "",
    issue_year: str = "",
    underwriter: str = "",
    grade: str = "",
) -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-数据-债券信息-信息查询
    https://www.chinamoney.com.cn/chinese/scsjzqxx/
    :param bond_name: 债券名称
    :type bond_name: str
    :param bond_code: 债券代码
    :type bond_code: str
    :param bond_issue: 发行人/受托机构
    :type bond_issue: str
    :param bond_type: 债券类型
    :type bond_type: str
    :param coupon_type: 息票类型
    :type coupon_type: str
    :param issue_year: 发行年份
    :type issue_year: str
    :param underwriter: 主承销商
    :type underwriter: str
    :param grade: 评级等级
    :type grade: str
    :return: 信息查询结果
    :rtype: pandas.DataFrame
    """
    bond_china_close_return_map()
    if bond_type:
        bond_type_df = bond_info_cm_query(symbol="债券类型")
        bond_type_df_value = bond_type_df[bond_type_df["name"] == bond_type][
            "code"
        ].values[0]
    else:
        bond_type_df_value = ""

    if coupon_type:
        coupon_type_df = bond_info_cm_query(symbol="息票类型")
        coupon_type_df_value = coupon_type_df[coupon_type_df["name"] == coupon_type][
            "code"
        ].values[0]
    else:
        coupon_type_df_value = ""

    if underwriter:
        underwriter_df = bond_info_cm_query(symbol="主承销商")
        underwriter_value = underwriter_df[underwriter_df["name"] == underwriter][
            "code"
        ].values[0]
    else:
        underwriter_value = ""

    url = "https://www.chinamoney.com.cn/ags/ms/cm-u-bond-md/BondMarketInfoList2"
    payload = {
        "pageNo": "1",
        "pageSize": "15",
        "bondName": bond_name,
        "bondCode": bond_code,
        "issueEnty": bond_issue,
        "bondType": bond_type_df_value if bond_type_df_value else "",
        "bondSpclPrjctVrty": "",
        "couponType": coupon_type_df_value if coupon_type_df_value else "",
        "issueYear": issue_year,
        "entyDefinedCode": underwriter_value if underwriter_value else "",
        "rtngShrt": grade,
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/109.0.0.0 Safari/537.36"
    }
    r = requests.post(url, data=payload, headers=headers)
    data_json = r.json()
    total_page = data_json["data"]["pageTotal"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        payload.update({"pageNo": page})
        r = requests.post(url, data=payload, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["resultList"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.rename(
        columns={
            "bondDefinedCode": "查询代码",
            "bondName": "债券简称",
            "bondCode": "债券代码",
            "issueStartDate": "发行日期",
            "issueEndDate": "-",
            "bondTypeCode": "-",
            "bondType": "债券类型",
            "entyFullName": "发行人/受托机构",
            "entyDefinedCode": "-",
            "debtRtng": "最新债项评级",
            "isin": "-",
            "inptTp": "-",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "债券简称",
            "债券代码",
            "发行人/受托机构",
            "债券类型",
            "发行日期",
            "最新债项评级",
            "查询代码",
        ]
    ]
    return big_df


@functools.lru_cache()
def bond_info_detail_cm(symbol: str = "淮安农商行CDSD2022021012") -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-数据-债券信息-信息查询-债券详情
    https://www.chinamoney.com.cn/chinese/zqjc/?bondDefinedCode=egfjh08154
    :param symbol: 债券简称
    :type symbol: str
    :return: 债券详情
    :rtype: pandas.DataFrame
    """
    bond_china_close_return_map()
    url = "https://www.chinamoney.com.cn/ags/ms/cm-u-bond-md/BondDetailInfo"
    inner_bond_info_cm_df = bond_info_cm(bond_name=symbol)
    bond_code = inner_bond_info_cm_df["查询代码"].values[0]
    payload = {"bondDefinedCode": bond_code}
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/109.0.0.0 Safari/537.36"
    }
    r = requests.post(url, data=payload, headers=headers)
    data_json = r.json()
    data_dict = data_json["data"]["bondBaseInfo"]
    if data_dict["creditRateEntyList"]:
        del data_dict["creditRateEntyList"]
    if data_dict["exerciseInfoList"]:
        del data_dict["exerciseInfoList"]
    temp_df = pd.DataFrame.from_dict(data_dict, orient="index")
    temp_df.reset_index(inplace=True)
    temp_df.columns = ["name", "value"]
    return temp_df


if __name__ == "__main__":
    bond_info_cm_df = bond_info_cm(
        bond_name="",
        bond_code="",
        bond_issue="",
        bond_type="短期融资券",
        coupon_type="零息式",
        issue_year="2019",
        grade="A-1",
        underwriter="重庆农村商业银行股份有限公司",
    )
    print(bond_info_cm_df)

    bond_info_detail_cm_df = bond_info_detail_cm(symbol="19万林投资CP001")
    print(bond_info_detail_cm_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/13 10:30
Desc: 同花顺-分红情况
https://basic.10jqka.com.cn/new/603444/bonus.html
"""

from io import StringIO

import pandas as pd
import requests


def stock_fhps_detail_ths(symbol: str = "603444") -> pd.DataFrame:
    """
    同花顺-分红情况
    https://basic.10jqka.com.cn/new/603444/bonus.html
    :param symbol: 股票代码
    :type symbol: str
    :return: 分红融资
    :rtype: pandas.DataFrame
    """
    url = f"https://basic.10jqka.com.cn/new/{symbol}/bonus.html"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
        "AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/89.0.4389.90 Safari/537.36",
    }
    r = requests.get(url, headers=headers)
    r.encoding = "gbk"
    temp_df = pd.read_html(StringIO(r.text))[0]
    temp_df["董事会日期"] = pd.to_datetime(
        temp_df["董事会日期"], format="%Y-%m-%d", errors="coerce"
    ).dt.date
    temp_df["股东大会预案公告日期"] = pd.to_datetime(
        temp_df["股东大会预案公告日期"], format="%Y-%m-%d", errors="coerce"
    ).dt.date
    temp_df["实施公告日"] = pd.to_datetime(
        temp_df["实施公告日"], format="%Y-%m-%d", errors="coerce"
    ).dt.date
    if "A股股权登记日" in temp_df.columns:
        temp_df["A股股权登记日"] = pd.to_datetime(
            temp_df["A股股权登记日"], format="%Y-%m-%d", errors="coerce"
        ).dt.date
        temp_df["A股除权除息日"] = pd.to_datetime(
            temp_df["A股除权除息日"], format="%Y-%m-%d", errors="coerce"
        ).dt.date
    else:
        temp_df["B股股权登记日"] = pd.to_datetime(
            temp_df["B股股权登记日"], format="%Y-%m-%d", errors="coerce"
        ).dt.date
        temp_df["B股除权除息日"] = pd.to_datetime(
            temp_df["B股除权除息日"], format="%Y-%m-%d", errors="coerce"
        ).dt.date
    temp_df.sort_values(by=["董事会日期"], ignore_index=True, inplace=True)
    return temp_df


if __name__ == "__main__":
    stock_fhps_detail_ths_df = stock_fhps_detail_ths(symbol="200596")
    print(stock_fhps_detail_ths_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2022/12/13 14:18
Desc: 天天基金网-基金数据-分红送配
https://fund.eastmoney.com/data/fundfenhong.html
"""

import pandas as pd
import requests
from tqdm import tqdm


def fund_fh_em() -> pd.DataFrame:
    """
    天天基金网-基金数据-分红送配-基金分红
    https://fund.eastmoney.com/data/fundfenhong.html#DJR,desc,1,,,
    :return: 基金分红
    :rtype: pandas.DataFrame
    """
    url = "http://fund.eastmoney.com/Data/funddataIndex_Interface.aspx"
    params = {
        "dt": "8",
        "page": "1",
        "rank": "BZDM",
        "sort": "asc",
        "gs": "",
        "ftype": "",
        "year": "",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    total_page = eval(data_text[data_text.find("=") + 1 : data_text.find(";")])[0]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params)
        data_text = r.text
        temp_list = eval(
            data_text[data_text.find("[[") : data_text.find(";var jjfh_jjgs")]
        )
        temp_df = pd.DataFrame(temp_list)
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df["index"] = big_df.index + 1
    big_df.columns = [
        "序号",
        "基金代码",
        "基金简称",
        "权益登记日",
        "除息日期",
        "分红",
        "分红发放日",
        "-",
    ]
    big_df = big_df[
        ["序号", "基金代码", "基金简称", "权益登记日", "除息日期", "分红", "分红发放日"]
    ]
    big_df["权益登记日"] = pd.to_datetime(big_df["权益登记日"]).dt.date
    big_df["除息日期"] = pd.to_datetime(big_df["除息日期"]).dt.date
    big_df["分红发放日"] = pd.to_datetime(big_df["分红发放日"]).dt.date
    big_df["分红"] = pd.to_numeric(big_df["分红"])
    return big_df


def fund_cf_em() -> pd.DataFrame:
    """
    天天基金网-基金数据-分红送配-基金拆分
    https://fund.eastmoney.com/data/fundchaifen.html#FSRQ,desc,1,,,
    :return: 基金拆分
    :rtype: pandas.DataFrame
    """
    url = "http://fund.eastmoney.com/Data/funddataIndex_Interface.aspx"
    params = {
        "dt": "9",
        "page": "1",
        "rank": "FSRQ",
        "sort": "desc",
        "gs": "",
        "ftype": "",
        "year": "",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    total_page = eval(data_text[data_text.find("=") + 1 : data_text.find(";")])[0]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params)
        data_text = r.text
        temp_str = data_text[data_text.find("[[") : data_text.find(";var jjcf_jjgs")]
        if temp_str:
            temp_list = eval(temp_str)
            temp_df = pd.DataFrame(temp_list)
            big_df = pd.concat([big_df, temp_df], ignore_index=True)

    big_df.reset_index(inplace=True)
    big_df.loc[:, "index"] = big_df["index"] + 1
    big_df.columns = [
        "序号",
        "基金代码",
        "基金简称",
        "拆分折算日",
        "拆分类型",
        "拆分折算",
        "-",
    ]
    big_df = big_df[
        ["序号", "基金代码", "基金简称", "拆分折算日", "拆分类型", "拆分折算"]
    ]
    big_df["拆分折算日"] = pd.to_datetime(big_df["拆分折算日"]).dt.date
    big_df["拆分折算"] = pd.to_numeric(big_df["拆分折算"], errors="coerce")
    return big_df


def fund_fh_rank_em() -> pd.DataFrame:
    """
    天天基金网-基金数据-分红送配-基金分红排行
    https://fund.eastmoney.com/data/fundleijifenhong.html
    :return: 基金分红排行
    :rtype: pandas.DataFrame
    """
    url = "http://fund.eastmoney.com/Data/funddataIndex_Interface.aspx"
    params = {
        "dt": "10",
        "page": "1",
        "rank": "FHFCZ",
        "sort": "desc",
        "gs": "",
        "ftype": "",
        "year": "",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    total_page = eval(data_text[data_text.find("=") + 1 : data_text.find(";")])[0]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url, params=params)
        data_text = r.text
        temp_list = eval(
            data_text[data_text.find("[[") : data_text.find(";var fhph_jjgs")]
        )
        temp_df = pd.DataFrame(temp_list)
        big_df = pd.concat([big_df, temp_df], ignore_index=True)

    big_df.reset_index(inplace=True)
    big_df.loc[:, "index"] = big_df.index + 1
    big_df.columns = [
        "序号",
        "基金代码",
        "基金简称",
        "累计分红",
        "累计次数",
        "成立日期",
        "-",
    ]
    big_df = big_df[
        ["序号", "基金代码", "基金简称", "累计分红", "累计次数", "成立日期"]
    ]
    big_df["成立日期"] = pd.to_datetime(big_df["成立日期"]).dt.date
    big_df["累计分红"] = pd.to_numeric(big_df["累计分红"], errors="coerce")
    big_df["累计次数"] = pd.to_numeric(big_df["累计次数"], errors="coerce")
    return big_df


if __name__ == "__main__":
    fund_fh_em_df = fund_fh_em()
    print(fund_fh_em_df)

    fund_cf_em_df = fund_cf_em()
    print(fund_cf_em_df)

    fund_fh_rank_em_df = fund_fh_rank_em()
    print(fund_fh_rank_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/3 16:00
Desc: 东方财富-经济数据-日本
https://data.eastmoney.com/cjsj/foreign_3_0.html
"""

import pandas as pd
import requests


def macro_japan_core(symbol: str = "EMG00341602") -> pd.DataFrame:
    """
    东方财富-数据中心-经济数据一览-宏观经济-日本-核心代码
    https://data.eastmoney.com/cjsj/foreign_1_0.html
    :param symbol: 代码
    :type symbol: str
    :return: 指定 symbol 的数据
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "reportName": "RPT_ECONOMICVALUE_JPAN",
        "columns": "ALL",
        "filter": f'(INDICATOR_ID="{symbol}")',
        "pageNumber": "1",
        "pageSize": "5000",
        "sortColumns": "REPORT_DATE",
        "sortTypes": "-1",
        "source": "WEB",
        "client": "WEB",
        "p": "1",
        "pageNo": "1",
        "pageNum": "1",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    temp_df.rename(
        columns={
            "COUNTRY": "-",
            "INDICATOR_ID": "-",
            "INDICATOR_NAME": "-",
            "REPORT_DATE_CH": "时间",
            "REPORT_DATE": "-",
            "PUBLISH_DATE": "发布日期",
            "VALUE": "现值",
            "PRE_VALUE": "前值",
            "INDICATOR_IDOLD": "-",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "时间",
            "前值",
            "现值",
            "发布日期",
        ]
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"], errors="coerce")
    temp_df["现值"] = pd.to_numeric(temp_df["现值"], errors="coerce")
    temp_df["发布日期"] = pd.to_datetime(temp_df["发布日期"], errors="coerce").dt.date
    temp_df.sort_values(["发布日期"], inplace=True, ignore_index=True)
    return temp_df


# 央行公布利率决议
def macro_japan_bank_rate() -> pd.DataFrame:
    """
    东方财富-经济数据-日本-央行公布利率决议
    https://data.eastmoney.com/cjsj/foreign_3_0.html
    :return: 央行公布利率决议
    :rtype: pandas.DataFrame
    """
    temp_df = macro_japan_core(symbol="EMG00342252")
    return temp_df


# 全国消费者物价指数年率
def macro_japan_cpi_yearly() -> pd.DataFrame:
    """
    东方财富-经济数据-日本-全国消费者物价指数年率
    https://data.eastmoney.com/cjsj/foreign_3_1.html
    :return: 全国消费者物价指数年率
    :rtype: pandas.DataFrame
    """
    temp_df = macro_japan_core(symbol="EMG00005004")
    return temp_df


# 全国核心消费者物价指数年率
def macro_japan_core_cpi_yearly() -> pd.DataFrame:
    """
    东方财富-经济数据-日本-全国核心消费者物价指数年率
    https://data.eastmoney.com/cjsj/foreign_2_2.html
    :return: 全国核心消费者物价指数年率
    :rtype: pandas.DataFrame
    """
    temp_df = macro_japan_core(symbol="EMG00158099")
    return temp_df


# 失业率
def macro_japan_unemployment_rate() -> pd.DataFrame:
    """
    东方财富-经济数据-日本-失业率
    https://data.eastmoney.com/cjsj/foreign_2_3.html
    :return: 失业率
    :rtype: pandas.DataFrame
    """
    temp_df = macro_japan_core(symbol="EMG00005047")
    return temp_df


# 领先指标终值
def macro_japan_head_indicator() -> pd.DataFrame:
    """
    东方财富-经济数据-日本-领先指标终值
    https://data.eastmoney.com/cjsj/foreign_3_4.html
    :return: 领先指标终值
    :rtype: pandas.DataFrame
    """
    temp_df = macro_japan_core(symbol="EMG00005117")
    return temp_df


if __name__ == "__main__":
    macro_japan_bank_rate_df = macro_japan_bank_rate()
    print(macro_japan_bank_rate_df)

    macro_japan_cpi_yearly_df = macro_japan_cpi_yearly()
    print(macro_japan_cpi_yearly_df)

    macro_japan_core_cpi_yearly_df = macro_japan_core_cpi_yearly()
    print(macro_japan_core_cpi_yearly_df)

    macro_japan_unemployment_rate_df = macro_japan_unemployment_rate()
    print(macro_japan_unemployment_rate_df)

    macro_japan_head_indicator_df = macro_japan_head_indicator()
    print(macro_japan_head_indicator_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/25 17:20
Desc: 河北省空气质量预报信息发布系统
https://110.249.223.67/publish
每日 17 时发布
等级划分
1. 空气污染指数为0－50，空气质量级别为一级，空气质量状况属于优。此时，空气质量令人满意，基本无空气污染，各类人群可正常活动。
2. 空气污染指数为51－100，空气质量级别为二级，空气质量状况属于良。此时空气质量可接受，但某些污染物可能对极少数异常敏感人群健康有较弱影响，建议极少数异常敏感人群应减少户外活动。
3. 空气污染指数为101－150，空气质量级别为三级，空气质量状况属于轻度污染。此时，易感人群症状有轻度加剧，健康人群出现刺激症状。建议儿童、老年人及心脏病、呼吸系统疾病患者应减少长时间、高强度的户外锻炼。
4. 空气污染指数为151－200，空气质量级别为四级，空气质量状况属于中度污染。此时，进一步加剧易感人群症状，可能对健康人群心脏、呼吸系统有影响，建议疾病患者避免长时间、高强度的户外锻练，一般人群适量减少户外运动。
5. 空气污染指数为201－300，空气质量级别为五级，空气质量状况属于重度污染。此时，心脏病和肺病患者症状显著加剧，运动耐受力降低，健康人群普遍出现症状，建议儿童、老年人和心脏病、肺病患者应停留在室内，停止户外运动，一般人群减少户外运动。
6. 空气污染指数大于300，空气质量级别为六级，空气质量状况属于严重污染。此时，健康人群运动耐受力降低，有明显强烈症状，提前出现某些疾病，建议儿童、老年人和病人应当留在室内，避免体力消耗，一般人群应避免户外活动。
发布单位：河北省环境应急与重污染天气预警中心 技术支持：中国科学院大气物理研究所 中科三清科技有限公司
"""

import pandas as pd
import requests
from bs4 import BeautifulSoup


def air_quality_hebei() -> pd.DataFrame:
    """
    河北省空气质量预报信息发布系统-空气质量预报, 未来 6 天
    http://218.11.10.130:8080/#/application/home
    :return: city = "", 返回所有地区的数据; city="唐山市", 返回唐山市的数据
    :rtype: pandas.DataFrame
    """
    url = "http://218.11.10.130:8080/api/hour/130000.xml"
    r = requests.get(url)
    soup = BeautifulSoup(r.content, features="xml")
    data = []
    cities = soup.find_all("City")
    for city in cities:
        pointers = city.find_all("Pointer")
        for pointer in pointers:
            row = {
                "City": city.Name.text if city.Name else None,
                "Region": pointer.Region.text if pointer.Region else None,
                "Station": pointer.Name.text if pointer.Name else None,
                "DateTime": pointer.DataTime.text if pointer.DataTime else None,
                "AQI": pointer.AQI.text if pointer.AQI else None,
                "Level": pointer.Level.text if pointer.Level else None,
                "MaxPoll": pointer.MaxPoll.text if pointer.MaxPoll else None,
                "Longitude": pointer.CLng.text if pointer.CLng else None,
                "Latitude": pointer.CLat.text if pointer.CLat else None,
            }
            polls = pointer.find_all("Poll")
            for poll in polls:
                poll_name = poll.Name.text if poll.Name else None
                poll_value = poll.Value.text if poll.Value else None
                row[f"{poll_name}_Value"] = poll_value
                row[f"{poll_name}_IAQI"] = poll.IAQI.text if poll.IAQI else None
            data.append(row)

    df = pd.DataFrame(data)
    numeric_columns = ["AQI", "Longitude", "Latitude"] + [
        col for col in df.columns if col.endswith("_Value") or col.endswith("_IAQI")
    ]
    for col in numeric_columns:
        df[col] = pd.to_numeric(df[col], errors="coerce")

    column_names = {
        "City": "城市",
        "Region": "区域",
        "Station": "监测点",
        "DateTime": "时间",
        "Level": "空气质量等级",
        "MaxPoll": "首要污染物",
        "Longitude": "经度",
        "Latitude": "纬度",
        "SO2_Value": "二氧化硫_浓度",
        "SO2_IAQI": "二氧化硫_IAQI",
        "CO_Value": "一氧化碳_浓度",
        "CO_IAQI": "一氧化碳_IAQI",
        "NO2_Value": "二氧化氮_浓度",
        "NO2_IAQI": "二氧化氮_IAQI",
        "O3-1H_Value": "臭氧1小时_浓度",
        "O3-1H_IAQI": "臭氧1小时_IAQI",
        "O3-8H_Value": "臭氧8小时_浓度",
        "O3-8H_IAQI": "臭氧8小时_IAQI",
        "PM2.5_Value": "PM2.5_浓度",
        "PM2.5_IAQI": "PM2.5_IAQI",
        "PM10_Value": "PM10_浓度",
        "PM10_IAQI": "PM10_IAQI",
    }
    df = df.rename(columns=column_names)
    basic_columns = [
        "城市",
        "区域",
        "监测点",
        "时间",
        "AQI",
        "空气质量等级",
        "首要污染物",
        "经度",
        "纬度",
    ]
    pollutant_columns = [col for col in df.columns if col not in basic_columns]
    df = df[basic_columns + sorted(pollutant_columns)]
    return df


if __name__ == "__main__":
    air_quality_hebei_df = air_quality_hebei()
    print(air_quality_hebei_df)
